﻿using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Rewrite;
using Microsoft.Net.Http.Headers;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace UrlRewrite
{
    public class MoviesRedirectRule : IRule
    {
        private readonly string[] _matchPaths;
        private readonly string _newPath;

        public MoviesRedirectRule(string[] matchPaths, string newPath)
        {
            _matchPaths = matchPaths;
            _newPath = newPath;
        }

        public void ApplyRule(RewriteContext context)
        {
            var request = context.HttpContext.Request;

            // 已经是目标地址了，直接返回
            if (request.Path.StartsWithSegments(new PathString(_newPath)))
            {
                return;
            }

            if (_matchPaths.Contains(request.Path.Value))
            {
                var newLocation = $"{_newPath}{request.QueryString}";

                var response = context.HttpContext.Response;
                response.StatusCode = StatusCodes.Status302Found;
                context.Result = RuleResult.EndResponse;
                response.Headers[HeaderNames.Location] = newLocation;
            }
        }
    }
}
